/*	---------------------------------------------------------------
 * Script:	ai-configure.js
 * Role:		Utility for the ai-config page:
 * 	a)	Enable the theme to be changed dynamically
 * 	b)	To select Dark mode for the theme
 * 	c)	Set static or scrolling header / footer
 * 	d)	Adjust padding above & below page content
 * Version:	1.0.4
 * Author:	Neil Thomas
 * Edited:	23 Mar 2023
 * Checked:
 * ---------------------------------------------------------------*/

//	Configure 'thems' for drop down
let ThemeNames = ["Almond Buff",		"Almost Mauve",	"Arcadia",		"Basic Grey", 
						"Cherry Tomato",	"Chili Oil",		"Crocus Petal","Cylon Yellow",
						"Default Blue",	"Emporador",		"Grey Blue",   "Grey Green", 
						"Grey Red",			"Harbour Mist",	"Limelight",   "LimePunch", 
						"Marsala",	      "Martini Olive",	"Meerkat",     "Nebulas Blue", 
						"Quiet Grey",	   "Red Pear",			"Russet Orange","Sailor Blue",
						"Sargasso Sea",	"Slate Grey",		"Spring Crocus","Tofu",
						"Ultra Violet",   "Valiant Poppy",	"Warm Sand"];


$( function () {
	if( typeof( Storage ) == 'undefined' ) {
		console.log( 'Local storage unavailable.' );
		$('#ThemeSelector').html("Your broswer won't allow on-line theme selection!");
	} else {
		if( $('#ThemeSelector').length ) {
			setupSelector( CMXConfig.Theme );
		}
	}
	displayCurrent();
//	$('input[type=radio]').bind('change', function() {
//		alert("Display mode: " + $('input[type=radio]:checked').val());
//	})
});

let displayCurrent = function() {
	//	Using CMXConfig variable rather than stored data
	console.log( "updating screen elements" );
	$('#BannerState').prop('checked' , (CMXConfig.StaticHead ? ' checked' : '' ));
	$('#FooterState').prop('checked', (CMXConfig.StaticFoot ? ' selected' : '' ));
	$('#darkMode').prop('checked', (CMXConfig.darkMode ? ' selected' : '' ));
	$('#paddingTop').prop('value', parseInt(CMXConfig.PaddingTop ));
	$('#paddingBottom').prop('value', parseInt(CMXConfig.PaddingBottom ));
};


let setupSelector = function( activeTheme ) {
	//	Set up option lists of available themes
	var theme, fileName;
	var selector = '<select id="ThemeList" class="w3-select ow-theme-l3 ow-theme-hvr" style="max-width:140px;">\n';
	for (theme = 0; theme < ThemeNames.length; theme++ ) { 
		fileName = ThemeNames[theme].replace(" ","");
		selector += '<option value="' + fileName + '" ' + ( activeTheme == fileName  ? "selected" : "" ) + '>' + ThemeNames[theme] + '</option>\n';
	}
	selector += "</option>\n";
	$('#ThemeSelector').html( selector );
//	console.log("Selector: " + selector );
};

let viewChanges = function() {
	//	Make chages locally only
	var newConfig = {'Theme': $('#ThemeList').val(), 'darkMode': $("#darkMode").is(':checked')};
	newConfig = Object.assign(newConfig, {'StaticHead': $('#BannerState').is(':checked'), 'StaticFoot': $('#FooterState').is(':checked')});
	newConfig = Object.assign(newConfig, {'PaddingTop': $('#paddingTop').val()+'px', 'PaddingBottom': $('#paddingBottom').val()+'px' } );
	CMXConfig = newConfig;
	setTheme();
	setupPage();
};

var clearScheme = function() {
   localStorage.removeItem("CMXai2");
   alert("Saved configuration removed");
   window.location.assign("ai-config.html");
};

var setScheme = function(destination) {
	//	Store the scheme
	var newConfig = {'Theme': $('#ThemeList').val(), 'darkMode': $("#darkMode").is(':checked')};
	newConfig = Object.assign(newConfig, {'StaticHead': $('#BannerState').is(':checked'), 'StaticFoot': $('#FooterState').is(':checked')});
	newConfig = Object.assign(newConfig, {'PaddingTop': $('#paddingTop').val()+'px', 'PaddingBottom': $('#paddingBottom').val()+'px' } );
	var code = JSON.stringify( newConfig);
	if( destination == 'store' ) {
		localStorage.setItem( 'CMXai2', code );
	}
	if( typeof( Storage ) !== "undefined" ) {
		console.log('Storing');
		localStorage.setItem( 'CMXai2', code );
		alert( "The current configuration is now stored for all pages" );
	} else {
		console.log( 'Displaying' );
		$( '#configCode' ).html( code.replaceAll( ',', ',<br>' ) );
		$( '#popup' ).addClass( 'w3-show' );
		var child = $( '.w3-modal' ).children( '.w3-modal-content' );
		var mHeight = $( child ).outerHeight( true );
		$( child ).css('margin-top', ( $( window ).height() - mHeight ) / 3 + 'px' );
	}
}
