/*	--------------------------------------------------
 *	Script:	    js/mysqlsettings.js
 *  Author:     Neil Thomas
 *  Last Edit:  14th Feb 2023
 *	Based on:   /js/mysqlsettings.js
 *          By:	Mark Crossley
 *	    Edited:	2022/07/31 22:50:27
 *  -------------------------------------------------
 *  Changelog (NT)
 * 	Removed api call for version data - now in Page-Manager.js
 * 	Altered all API calls to use host root
 * 	Altered any json options / schema calls to use host root
 * 	Edited function getCSSRul() to omit first stylesheet - external!
 * -------------------------------------------------------------------*/

// Last modified: 2022/07/31 22:50:27

let accessMode;

$(document).ready(function () {
    $("form").alpaca({
        "dataSource": "/api/settings/mysqldata.json",
        "optionsSource": "/json/MySqlOptions.json",
        "schemaSource": "/json/MySqlSchema.json",
        "ui": "bootstrap",
        "view": "bootstrap-edit-horizontal",
        "options": {
            "form": {
                "buttons": {
                    // don't use the Submit button because that is disabled on validation errors
                    "validate": {
                        "title": "Save Settings",
                        "click": function() {
                            this.refreshValidationState(true);
                            if (this.isValid(true)) {
                                let json = this.getValue();

                                $.ajax({
                                    type: "POST",
                                    url: "/api/setsettings/updatemysqlconfig.json",
                                    data: {json: JSON.stringify(json)},
                                    dataType: "text"
                                })
                                .done(function () {
                                    alert("Settings updated");
                                })
                                .fail(function (jqXHR, textStatus) {
                                    alert("Error: " + jqXHR.status + "(" + textStatus + ") - " + jqXHR.responseText);
                                });
                            } else {
                                let firstErr = $('form').find(".has-error:first")
                                let path = $(firstErr).attr('data-alpaca-field-path');
                                let msg = $(firstErr).children('.alpaca-message').text();
                                alert("Invalid value in the form: " + path + msg);
                                if ($(firstErr).is(":visible")) {
                                    let entry = $(firstErr).focus();
                                    $(window).scrollTop($(entry).position().top);
                                }
                            }
                        },
                        "styles": "alpaca-form-button-submit"
                    }
                }
            }
        },
        "postRender": function (form) {
            // Change in accessibility is enabled
            let accessObj = form.childrenByPropertyId["accessible"];
            onAccessChange(null, accessObj.getValue());
            accessMode = accessObj.getValue();

            if (!accessMode) {
                setCollapsed();  // sets the class and aria attribute missing on first load by Alpaca
            }

            // Trigger changes is the accessibility mode is changed
            //accessObj.on("change", function() {onAccessChange(this)});
        }
    });

    $("#createmonthly").click(function () {
        $("#results").text("Attempting create...");
        $.ajax({
            type: "POST",
            url: "/api/setsettings/createmonthlysql.json",
            success: function (msg) {
                $("#results").text(msg.result);
                timeOut("results");
            },
            error: function (xhr, textStatus, error) {
                $("#results").text(textStatus);
                timeOut("results");
            }
        });
    });

    $("#createdayfile").click(function () {
        $("#results").text("Attempting create...");
        $.ajax({
            type: "POST",
            url: "/api/setsettings/createdayfilesql.json",
            success: function (msg) {
                $("#results").text(msg.result);
                timeOut("results");
            },
            error: function (xhr, textStatus, error) {
                $("#results").text(textStatus);
                timeOut("results");
            }
        });
    });

    $("#createrealtime").click(function () {
        $("#results").text("Attempting create...");
        $.ajax({
            type: "POST",
            url: "/api/setsettings/createrealtimesql.json"
        })
        .done(function (msg) {
            $("#results").text(msg.result);
            timeOut("results");
        })
        .fail(function (jqXHR, textStatus) {
            alert("Error: " + jqXHR.status + "(" + textStatus + ") - " + jqXHR.responseText);
        });
    });


    $("#updatemonthly").click(function () {
        $("#results").text("Attempting update...");
        $.ajax({
            type: "POST",
            url: "/api/setsettings/updatemonthlysql.json",
            success: function (msg) {
                $("#results").text(msg.result);
                console.log("Update Monthly: " + msg.result);
            },
            error: function (xhr, textStatus, error) {
                $("#results").text(textStatus);
                console.log("Update Monthly returned an error: " + error);
            }
        });
        timeOut("results");
    });

    $("#updatedayfile").click(function () {
        $("#results").text("Attempting update...");
        $.ajax({
            type: "POST",
            url: "/api/setsettings/updatedayfilesql.json",
            success: function (msg) {
                $("#results").text(msg.result);
                timeOut("results");
            },
            error: function (xhr, textStatus, error) {
                $("#results").text(textStatus);
                timeOut("results");
            }
        });
    });

    $("#updaterealtime").click(function () {
        $("#results").text("Attempting update...");
        $.ajax({
            type: "POST",
            url: "/api/setsettings/updaterealtimesql.json"
        })
        .done(function (msg) {
            $("#results").text(msg.result);
            timeOut("results");
        })
        .fail(function (jqXHR, textStatus) {
            alert("Error: " + jqXHR.status + "(" + textStatus + ") - " + jqXHR.responseText);
        });
    });

});

function addButtons() {
    $('form legend').each(function () {
        let span = $('span:first',this);
        if (span.length === 0)
            return;

            let butt = $('<button type="button" data-toggle="collapse" data-target="' +
            $(span).attr('data-target') +
            '" role="treeitem" aria-expanded="false" class="collapsed">' +
            $(span).text() +
            '</button>');
        $(span).remove();
        $(this).prepend(butt);
    });
}

function removeButtons() {
    $('form legend').each(function () {
        let butt = $('button:first',this);
        if (butt.length === 0)
            return;

            let span = $('<span data-toggle="collapse" data-target="' +
            $(butt).attr('data-target') +
            '" role="treeitem" aria-expanded="false" class="collapsed">' +
            $(butt).text() +
            '</span>');
        $(butt).remove();
        $(this).prepend(span);
    });
}

function setCollapsed() {
    $('form div.alpaca-container.collapse').each(function () {
        let span = $(this).siblings('legend:first').children('span:first');
        if ($(this).hasClass('in')) {
            span.attr('role', 'treeitem');
            span.attr('aria-expanded', true);
        } else {
            span.attr('role', 'treeitem');
            span.attr('aria-expanded', false);
            span.addClass('collapsed')
        }
    });
}

function getCSSRule(search) {
    for (let x = 1; x < document.styleSheets.length; x++) {
        let rules = document.styleSheets[x].rules || document.styleSheets[x].cssRules;
        for (let i = 0; i < rules.length; i++) {
            if (rules[i].selectorText && rules[i].selectorText.lastIndexOf(search) === 0  && search.length === rules[i].selectorText.length) {
                return rules[i];
            }
        }
    }
    return null;
}

function onAccessChange(that, val) {
    let mode = val == null ? that.getValue() : val;
    if (mode == accessMode) {
        return;
    }

    let expandable = getCSSRule('.alpaca-field > legend > .collapsed::before');
    let expanded = getCSSRule('.alpaca-field > legend > span::before');

    accessMode = mode;
    if (mode) {
        expandable.style.setProperty('display','none');
        expanded.style.setProperty('display','none');
        addButtons();
    } else {
        expandable.style.removeProperty('display');
        expanded.style.removeProperty('display');
        removeButtons();
    }
}

//  --  Timout for status messages        
let timeOut = function(elId) {
    window.setTimeout( function(){$("#" + elId).html("&nbsp;");}, 4000);
};
